define(
//begin v1.x content
{
	"dateFormatItem-yMMMM": "LLLL y",
	"field-thu-narrow-relative+0": "w ten czwartek",
	"field-thu-narrow-relative+1": "w przyszły czwartek",
	"field-sun-narrow-relative+0": "w tę niedzielę",
	"field-sun-narrow-relative+1": "w przyszłą niedzielę",
	"months-format-wide": [
		"stycznia",
		"lutego",
		"marca",
		"kwietnia",
		"maja",
		"czerwca",
		"lipca",
		"sierpnia",
		"września",
		"października",
		"listopada",
		"grudnia"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "w ten piątek",
	"field-fri-narrow-relative+1": "w przyszły piątek",
	"eraNarrow": [
		"p.n.e.",
		"n.e."
	],
	"dateFormatItem-Hmv": "HH:mm v",
	"dateFormatItem-hmsv": "h:mm:ss a v",
	"dateFormatItem-yMMMd": "d MMM y",
	"dayPeriods-format-abbr-night1": "w nocy",
	"dayPeriods-format-narrow-evening1": "wiecz.",
	"days-standAlone-narrow": [
		"N",
		"P",
		"W",
		"Ś",
		"C",
		"P",
		"S"
	],
	"days-standAlone-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"dayPeriods-format-abbr-afternoon1": "po południu",
	"dayPeriods-format-wide-evening1": "wieczorem",
	"dateFormatItem-Ehm": "E, h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "w zeszłą środę",
	"dayPeriods-standAlone-wide-evening1": "wieczór",
	"days-format-wide": [
		"niedziela",
		"poniedziałek",
		"wtorek",
		"środa",
		"czwartek",
		"piątek",
		"sobota"
	],
	"field-month-short-relative+0": "w tym mies.",
	"field-month-short-relative+1": "w przyszłym mies.",
	"dateFormatItem-Ehms": "E, h:mm:ss a",
	"dayPeriods-standAlone-narrow-evening1": "wiecz.",
	"dayPeriods-standAlone-abbr-afternoon1": "popołudnie",
	"field-thu-relative+0": "w ten czwartek",
	"dayPeriods-standAlone-abbr-night1": "noc",
	"field-thu-relative+1": "w przyszły czwartek",
	"dayPeriods-format-wide-am": "AM",
	"field-fri-relative+0": "w ten piątek",
	"field-fri-relative+1": "w przyszły piątek",
	"dateFormatItem-yMd": "d.MM.y",
	"field-thu-narrow-relative+-1": "w zeszły czwartek",
	"field-quarter-relative+0": "w tym kwartale",
	"field-quarter-relative+1": "w przyszłym kwartale",
	"field-sun-short-relative+0": "w tę niedzielę",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "w przyszłą niedzielę",
	"dateFormatItem-hms": "h:mm:ss a",
	"dayPeriods-format-narrow-afternoon1": "po poł.",
	"dateFormatItem-Md": "d.MM",
	"dateFormatItem-Hmsv": "HH:mm:ss v",
	"dateFormatItem-hmv": "h:mm a v",
	"field-week-narrow": "tydz.",
	"field-hour-relative+0": "ta godzina",
	"field-day-relative+-1": "wczoraj",
	"field-day-relative+-2": "przedwczoraj",
	"field-mon-narrow-relative+-1": "w zeszły poniedziałek",
	"field-minute-narrow": "min",
	"dateFormatItem-MMMMEd": "E, d MMMM",
	"dateFormatItem-GyMMMMEd": "E, d MMMM y G",
	"field-thu-short-relative+0": "w ten czwartek",
	"field-mon-relative+0": "w ten poniedziałek",
	"field-thu-short-relative+1": "w przyszły czwartek",
	"field-mon-relative+1": "w przyszły poniedziałek",
	"field-day-narrow-relative+0": "dziś",
	"field-era-short": "era",
	"field-day-narrow-relative+1": "jutro",
	"field-sat-narrow-relative+0": "w tę sobotę",
	"field-day-narrow-relative+2": "pojutrze",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "w przyszłą sobotę",
	"field-week-narrow-relative+0": "w tym tyg.",
	"field-week-narrow-relative+1": "w przyszłym tyg.",
	"field-wed-narrow-relative+0": "w tę środę",
	"field-wed-narrow-relative+1": "w przyszłą środę",
	"field-month": "miesiąc",
	"months-standAlone-wide": [
		"styczeń",
		"luty",
		"marzec",
		"kwiecień",
		"maj",
		"czerwiec",
		"lipiec",
		"sierpień",
		"wrzesień",
		"październik",
		"listopad",
		"grudzień"
	],
	"field-weekday-narrow": "dz. tyg.",
	"dayPeriods-standAlone-narrow-afternoon1": "popoł.",
	"field-year-relative+0": "w tym roku",
	"field-year-relative+1": "w przyszłym roku",
	"dayPeriods-format-abbr-evening1": "wieczorem",
	"dayPeriods-format-abbr-noon": "w południe",
	"dayPeriods-format-narrow-midnight": "o półn.",
	"dayPeriods-format-wide-midnight": "o północy",
	"field-tue-relative+0": "w ten wtorek",
	"dateFormatItem-GyMMMMd": "d MMMM y G",
	"field-tue-relative+1": "w przyszły wtorek",
	"dayPeriods-standAlone-abbr-evening1": "wieczór",
	"dateFormatItem-hm": "h:mm a",
	"dayPeriods-standAlone-wide-midnight": "północ",
	"field-year-narrow": "r.",
	"dayPeriods-standAlone-abbr-noon": "południe",
	"field-tue-short-relative+0": "w ten wtorek",
	"dayPeriods-standAlone-narrow-midnight": "półn.",
	"field-tue-short-relative+1": "w przyszły wtorek",
	"field-tue-narrow-relative+0": "w ten wtorek",
	"field-tue-narrow-relative+1": "w przyszły wtorek",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "w tę środę",
	"field-wed-relative+1": "w przyszłą środę",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "w tę środę",
	"field-fri-short-relative+0": "w ten piątek",
	"field-wed-short-relative+1": "w przyszłą środę",
	"field-fri-short-relative+1": "w przyszły piątek",
	"field-weekOfMonth-short": "tydz. mies.",
	"field-quarter-short-relative+-1": "w zeszłym kwartale",
	"field-year-short-relative+-1": "w zeszłym roku",
	"dateFormatItem-Bhm": "h:mm B",
	"dayPeriods-format-wide-night1": "w nocy",
	"dateTimeFormat-medium": "{1}, {0}",
	"field-quarter-narrow-relative+-1": "w zeszłym kwartale",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"field-weekOfMonth-narrow": "tydz. mies.",
	"dateFormatItem-y": "y",
	"field-minute-relative+0": "ta minuta",
	"field-year-short-relative+0": "w tym roku",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "w przyszłym roku",
	"field-weekday": "dzień tygodnia",
	"dayPeriods-format-narrow-pm": "p",
	"field-tue-narrow-relative+-1": "w zeszły wtorek",
	"dateFormatItem-yMEd": "E, d.MM.y",
	"dayPeriods-standAlone-wide-night1": "noc",
	"field-year-narrow-relative+-1": "w zeszłym roku",
	"field-sat-relative+-1": "w zeszłą sobotę",
	"dayPeriods-format-abbr-midnight": "o północy",
	"dayPeriods-format-narrow-morning1": "rano",
	"dayPeriods-format-narrow-morning2": "przed poł.",
	"dayPeriods-format-wide-morning1": "rano",
	"dayPeriods-format-wide-morning2": "przed południem",
	"dayPeriods-standAlone-abbr-midnight": "północ",
	"dayPeriods-standAlone-narrow-pm": "p",
	"dayPeriods-standAlone-wide-morning1": "rano",
	"field-mon-narrow-relative+0": "w ten poniedziałek",
	"dayPeriods-standAlone-wide-morning2": "przedpołudnie",
	"field-mon-narrow-relative+1": "w przyszły poniedziałek",
	"field-second": "sekunda",
	"dateFormatItem-yMMMEd": "E, d MMM y",
	"field-year-relative+-1": "w zeszłym roku",
	"field-weekdayOfMonth-short": "dzień mies.",
	"dateFormat-short": "dd.MM.y",
	"eraNames": [
		"przed naszą erą",
		"naszej ery"
	],
	"field-second-short": "sek.",
	"field-thu-short-relative+-1": "w zeszły czwartek",
	"field-zone": "strefa czasowa",
	"field-dayperiod-narrow": "rano / po poł. / wiecz.",
	"field-sun-short-relative+-1": "w zeszłą niedzielę",
	"dayPeriods-standAlone-narrow-morning1": "rano",
	"dayPeriods-standAlone-narrow-morning2": "przedpoł.",
	"eraAbbr": [
		"p.n.e.",
		"n.e."
	],
	"field-week-short": "tydz.",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "dzisiaj",
	"field-day-relative+1": "jutro",
	"field-day-relative+2": "pojutrze",
	"field-dayOfYear-short": "dz. roku",
	"dateFormat-long": "d MMMM y",
	"field-day-short-relative+2": "pojutrze",
	"field-sun-narrow-relative+-1": "w zeszłą niedzielę",
	"dayPeriods-format-wide-noon": "w południe",
	"field-second-relative+0": "teraz",
	"field-quarter-relative+-1": "w zeszłym kwartale",
	"dayPeriods-format-narrow-night1": "w nocy",
	"quarters-format-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"dayPeriods-standAlone-wide-noon": "południe",
	"dayPeriods-standAlone-narrow-night1": "noc",
	"field-week-relative+-1": "w zeszłym tygodniu",
	"dayPeriods-format-abbr-morning1": "rano",
	"field-month-relative+-1": "w zeszłym miesiącu",
	"dayPeriods-format-abbr-morning2": "przed południem",
	"months-format-narrow": [
		"s",
		"l",
		"m",
		"k",
		"m",
		"c",
		"l",
		"s",
		"w",
		"p",
		"l",
		"g"
	],
	"field-year": "rok",
	"field-era": "era",
	"dayPeriods-standAlone-abbr-morning1": "rano",
	"dayPeriods-standAlone-abbr-morning2": "przedpołudnie",
	"days-standAlone-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"dateFormatItem-yQQQQ": "QQQQ y",
	"field-day-short-relative+-2": "przedwczoraj",
	"dateFormatItem-GyMMM": "MMM y G",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "godzina",
	"field-dayOfYear-narrow": "dz. r.",
	"field-quarter": "kwartał",
	"field-month-narrow-relative+0": "w tym mies.",
	"field-month-narrow-relative+1": "w przyszłym mies.",
	"dateFormatItem-GyMMMM": "LLLL y G",
	"field-day": "dzień",
	"field-mon-relative+-1": "w zeszły poniedziałek",
	"field-dayOfYear": "dzień roku",
	"dateFormat-medium": "d MMM y",
	"dateTimeFormat-short": "{1}, {0}",
	"dateFormatItem-yMMM": "LLL y",
	"dateFormatItem-GyMMMd": "d MMM y G",
	"dateFormatItem-MEd": "E, d.MM",
	"field-tue-short-relative+-1": "w zeszły wtorek",
	"field-year-short": "r.",
	"field-month-short": "mies.",
	"dateFormatItem-MMMEd": "E, d MMM",
	"dayPeriods-format-wide-afternoon1": "po południu",
	"dateFormatItem-MMMd": "d MMM",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"sty",
		"lut",
		"mar",
		"kwi",
		"maj",
		"cze",
		"lip",
		"sie",
		"wrz",
		"paź",
		"lis",
		"gru"
	],
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "w tę sobotę",
	"field-sat-relative+1": "w przyszłą sobotę",
	"dayPeriods-format-wide-pm": "PM",
	"field-zone-short": "str. czasowa",
	"days-standAlone-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"field-week-short-relative+0": "w tym tyg.",
	"dateFormatItem-yMMMMd": "d MMMM y",
	"field-week-short-relative+1": "w przyszłym tyg.",
	"dayPeriods-standAlone-wide-afternoon1": "popołudnie",
	"field-fri-short-relative+-1": "w zeszły piątek",
	"field-month-narrow": "mc",
	"dayPeriods-format-narrow-am": "a",
	"field-month-narrow-relative+-1": "w zeszłym mies.",
	"days-format-abbr": [
		"niedz.",
		"pon.",
		"wt.",
		"śr.",
		"czw.",
		"pt.",
		"sob."
	],
	"field-weekday-short": "dzień tyg.",
	"field-day-narrow-relative+-1": "wcz.",
	"field-day-narrow-relative+-2": "przedwczoraj",
	"field-quarter-short": "kw.",
	"days-format-short": [
		"nie",
		"pon",
		"wto",
		"śro",
		"czw",
		"pią",
		"sob"
	],
	"months-standAlone-narrow": [
		"S",
		"L",
		"M",
		"K",
		"M",
		"C",
		"L",
		"S",
		"W",
		"P",
		"L",
		"G"
	],
	"days-format-narrow": [
		"n",
		"p",
		"w",
		"ś",
		"c",
		"p",
		"s"
	],
	"dateFormatItem-EHm": "E, HH:mm",
	"field-quarter-narrow": "kw.",
	"field-mon-short-relative+0": "w ten poniedziałek",
	"field-mon-short-relative+1": "w przyszły poniedziałek",
	"field-dayperiod-short": "rano / po południu / wieczorem",
	"dayPeriods-standAlone-narrow-am": "a",
	"field-week-narrow-relative+-1": "w zeszłym tyg.",
	"field-thu-relative+-1": "w zeszły czwartek",
	"field-fri-narrow-relative+-1": "w zeszły piątek",
	"field-mon-short-relative+-1": "w zeszły poniedziałek",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "w tym kwartale",
	"field-quarter-short-relative+1": "w przyszłym kwartale",
	"dateFormatItem-Ed": "E, d",
	"field-wed-relative+-1": "w zeszłą środę",
	"field-weekOfMonth": "tydzień miesiąca",
	"field-weekdayOfMonth-narrow": "dz. mies.",
	"dayPeriods-standAlone-wide-am": "AM",
	"dateFormatItem-yQQQ": "QQQ y",
	"field-fri-relative+-1": "w zeszły piątek",
	"field-minute": "minuta",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"quarters-format-wide": [
		"I kwartał",
		"II kwartał",
		"III kwartał",
		"IV kwartał"
	],
	"field-day-short": "dz.",
	"field-dayperiod": "rano / po południu / wieczorem",
	"field-hour-short": "godz.",
	"months-standAlone-abbr": [
		"sty",
		"lut",
		"mar",
		"kwi",
		"maj",
		"cze",
		"lip",
		"sie",
		"wrz",
		"paź",
		"lis",
		"gru"
	],
	"field-second-narrow": "s",
	"field-month-relative+0": "w tym miesiącu",
	"field-month-relative+1": "w przyszłym miesiącu",
	"dateFormat-full": "EEEE, d MMMM y",
	"field-era-narrow": "era",
	"field-sat-short-relative+-1": "w zeszłą sobotę",
	"dayPeriods-format-narrow-noon": "w poł.",
	"field-week-short-relative+-1": "w zeszłym tyg.",
	"dateFormatItem-yMMMMEd": "E, d MMMM y",
	"dateTimeFormat-long": "{1} {0}",
	"dateFormatItem-yM": "MM.y",
	"field-sun-relative+-1": "w zeszłą niedzielę",
	"field-wed-short-relative+-1": "w zeszłą środę",
	"field-weekdayOfMonth": "dzień miesiąca",
	"field-quarter-narrow-relative+0": "w tym kwartale",
	"dateFormatItem-GyMMMEd": "E, d MMM y G",
	"field-quarter-narrow-relative+1": "w przyszłym kwartale",
	"field-sat-short-relative+0": "w tę sobotę",
	"field-hour-narrow": "g.",
	"field-sat-short-relative+1": "w przyszłą sobotę",
	"field-year-narrow-relative+0": "w tym roku",
	"field-year-narrow-relative+1": "w przyszłym roku",
	"dateFormatItem-Gy": "y G",
	"field-zone-narrow": "str. czas.",
	"dayPeriods-standAlone-narrow-noon": "poł.",
	"field-tue-relative+-1": "w zeszły wtorek",
	"field-minute-short": "min",
	"dateFormatItem-yw": "Y, 'tydz'. w",
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "w tym tygodniu",
	"field-week-relative+1": "w przyszłym tygodniu",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "w tę niedzielę",
	"field-sun-relative+1": "w przyszłą niedzielę",
	"field-sat-narrow-relative+-1": "w zeszłą sobotę",
	"quarters-standAlone-abbr": [
		"I kw.",
		"II kw.",
		"III kw.",
		"IV kw."
	],
	"dateFormatItem-MMMMW": "LLLL, 'tydz'. W",
	"field-month-short-relative+-1": "w zeszłym mies.",
	"dateFormatItem-EHms": "E, HH:mm:ss",
	"dateFormatItem-MMMMd": "d MMMM",
	"field-week": "tydzień",
	"field-day-narrow": "d."
}
//end v1.x content
);